# jamegresc
目黒区の年度別の資源ごみ回収量・売却益の可視化をしています。
範囲は2011~2019年の間です。
y軸は左が回収量(t)、右が売却益(1000円)です。

visualizes the amount of recyclable waste collected and proceeds from the sale of recyclable waste by year in Meguro City.
The range is between 2011~2019.
The y-axis is the amount collected (tons) on the left and the profit from sale (1000 yen) on the right.

# Dataset
・jamegrescは以下のページからデータをダウンロードして利用しています。\
・jamegresc uses the data downloaded from the following page.

https://catalog.data.metro.tokyo.lg.jp/dataset/t131105d0000000018/resource/31bb126f-6f10-433a-9f65-d00986c48385


・jamegrescは、以下の著作物を改変・加工して利用しています。\
・jamegresc uses the following copyrighted materials by modifying and processing them.

著作物のタイトル　資源回収量・収集拠点数・売却益、\
著作権者　東京都・目黒区、\
クリエイティブ・コモンズ・ライセンス 表示4.0国際（ https://creativecommons.org/licenses/by/4.0/deed.ja ）

# 実行例
```zsh
python meguro_resc.py
```
![びん](/img/びん.png)



